Index: media/base/android/media_source_player.cc |
diff --git a/media/base/android/media_source_player.cc b/media/base/android/media_source_player.cc |
index 2be0d8b23471441f19d157987d0b09aa6f072c1f..6200e1ca6be18eda041ed3302c72765352d13b95 100644 |
--- a/media/base/android/media_source_player.cc |
+++ b/media/base/android/media_source_player.cc |
@@ -522,10 +522,10 @@ void MediaSourcePlayer::MediaDecoderCallback( |
// and video in one file. If we separate them, we should be able to remove a |
// lot of duplication. |
// If the status is MEDIA_CODEC_STOPPED, stop decoding new data. The player is |
// in the middle of a seek or stop event and needs to wait for the IPCs to |
// come. |
- if (status == MEDIA_CODEC_STOPPED) |
+ if (status == MEDIA_CODEC_ABORT) |
return; |
if (prerolling_ && IsPrerollFinished(is_audio)) { |
@@ -522,10 +522,10 @@ void MediaSourcePlayer::MediaDecoderCallback( |
// and video in one file. If we separate them, we should be able to remove a |
// lot of duplication. |
- // If the status is MEDIA_CODEC_STOPPED, stop decoding new data. The player is |
+ // If the status is MEDIA_CODEC_ABORT, stop decoding new data. The player is |
// in the middle of a seek or stop event and needs to wait for the IPCs to |
// come. |